@@ -1,10 +1,5 @@
 # Apache::ConfigParser: Load Apache configuration file.
 #
-# $HeadURL: http://www.orcaware.com/svn/repos/perl_apache_configparser/tags/1.01/lib/Apache/ConfigParser.pm $
-# $LastChangedRevision: 511 $
-# $LastChangedDate: 2005-11-22 20:42:24 -0800 (Tue, 22 Nov 2005) $
-# $LastChangedBy: blair@orcaware.com $
-#
 # Copyright (C) 2001-2005 Blair Zajac.  All rights reserved.
 
 package Apache::ConfigParser;
@@ -44,7 +39,7 @@ Apache::ConfigParser - Load Apache configuration files
   my $d_name = $directives[0]->name;
 
   # This directive appeared in this file, which may be in an Include'd
-  # file.
+  # or IncludeOptional'd file.
   my $d_filename = $directives[0]->filename;
 
   # And it begins on this line number.
@@ -146,7 +141,7 @@ use Apache::ConfigParser::Directive      qw(DEV_NULL
 
 use vars qw(@ISA $VERSION);
 @ISA     = qw(Exporter);
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 # This constant is used throughout the module.
 my $INCORRECT_NUMBER_OF_ARGS = "passed incorrect number of arguments.\n";
@@ -206,7 +201,7 @@ the directive name and if you do not want to modify the filename,
 return the subroutine's third argument.
 
 If the subroutine returns an undefined value or a value with 0 length,
-then it is replaced with <File::Spec->devnull> which is the
+then it is replaced with C<< File::Spec->devnull >> which is the
 appropriate 0 length file for the operating system.  This is done to
 keep a value in the directive name since otherwise the directive may
 not work properly.  For example, with the input
@@ -258,7 +253,7 @@ the directive name and if you do not want to modify the filename,
 return the subroutine's third argument.
 
 If the subroutine returns an undefined value or a value with 0 length,
-then it is replaced with <File::Spec->devnull> which is the
+then it is replaced with C<< File::Spec->devnull >> which is the
 appropriate 0 length file for the operating system.  This is done to
 keep a value in the directive name since otherwise the directive may
 not work properly.  For example, with the input
@@ -369,11 +364,11 @@ sub path_has_apache_style_glob {
   return $path =~ /[?*]/ || $path =~ /\[.*\]/;
 }
 
-# Handle the AccessConfig, Include or ResourceConfig directives.
-# Support the Apache 1.3.13 behavior where if the path is a directory
-# then Apache will recursively load all of the files in that
-# directory.  Support the Apache 1.3.27 and 2.0.41 behavior where if
-# the path contains any glob characters, then load the files and
+# Handle the AccessConfig, Include, IncludeOptional or ResourceConfig
+# directives.  Support the Apache 1.3.13 behavior where if the path is
+# a directory then Apache will recursively load all of the files in
+# that directory.  Support the Apache 1.3.27 and 2.0.41 behavior where
+# if the path contains any glob characters, then load the files and
 # directories recursively that match the glob.
 sub _handle_include_directive {
   unless (@_ == 5) {
@@ -493,7 +488,7 @@ configuration file did not close all of its contexts, such as
 C<$filename> will be added to the existing context.
 
 If there is a failure in parsing any portion of the configuration
-file, then this method returns undef and C<$c->errstr> will contain a
+file, then this method returns undef and C<< $c->errstr >> will contain a
 string explaining the error.
 
 =cut
@@ -756,10 +751,12 @@ sub parse_file {
       next;
     }
 
-    # If this directive is AccessConfig, Include or ResourceConfig,
-    # then include the indicated file(s) given by the path.
-    if ($directive eq 'accessconfig' or
-        $directive eq 'include'      or
+    # If this directive is AccessConfig, Include, IncludeOptional or
+    # ResourceConfig, then include the indicated file(s) given by the
+    # path.
+    if ($directive eq 'accessconfig'    or
+        $directive eq 'include'         or
+        $directive eq 'includeoptional' or
         $directive eq 'resourceconfig') {
       unless ($new_node->value_is_path) {
         next;
