@@ -1,10 +1,5 @@
 # Apache::ConfigParser::Directive: A single Apache directive or start context.
 #
-# $HeadURL: http://www.orcaware.com/svn/repos/perl_apache_configparser/tags/1.01/lib/Apache/ConfigParser/Directive.pm $
-# $LastChangedRevision: 511 $
-# $LastChangedDate: 2005-11-22 20:42:24 -0800 (Tue, 22 Nov 2005) $
-# $LastChangedBy: blair@orcaware.com $
-#
 # Copyright (C) 2001-2005 Blair Zajac.  All rights reserved.
 
 package Apache::ConfigParser::Directive;
@@ -19,7 +14,7 @@ use Tree::DAG_Node 1.04;
 
 use vars qw(@EXPORT_OK @ISA $VERSION);
 @ISA     = qw(Tree::DAG_Node Exporter);
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 # Determine if the filenames are case sensitive.
 use constant CASE_SENSITIVE_PATH => (! File::Spec->case_tolerant);
@@ -678,7 +673,7 @@ sub value_is_path {
 
 =item $d->orig_value_is_path($index_into_value_array)
 
-This has the same behavior as C<$d->value_is_path> except the results
+This has the same behavior as C<< $d->value_is_path >> except the results
 are applicable to C<$d>'s 'original' value array.
 
 =cut
@@ -733,7 +728,7 @@ sub value_is_abs_path {
 
 =item $d->orig_value_is_abs_path($index_into_value_array)
 
-This has the same behavior as C<$d->value_is_abs_path> except the
+This has the same behavior as C<< $d->value_is_abs_path >> except the
 results are applicable to C<$d>'s 'original' value array.
 
 =cut
@@ -788,7 +783,7 @@ sub value_is_rel_path {
 
 =item $d->orig_value_is_rel_path($index_into_value_array)
 
-This has the same behavior as C<$d->value_is_rel_path> except the
+This has the same behavior as C<< $d->value_is_rel_path >> except the
 results are applicable to C<$d>'s 'original' value array.
 
 =cut
@@ -893,7 +888,7 @@ takes only absolute, only relative or both types of paths.
 
 The hash value for the lowercase directive name is a subroutine
 reference.  The subroutine returns 1 if its only argument is a path
-and 0 otherwise.  The /dev/null equivalent (C<File::Spec->devnull>)
+and 0 otherwise.  The /dev/null equivalent (C<< File::Spec->devnull >>)
 for the operating system being used is not counted as a path, since on
 some operating systems the /dev/null equivalent is not a filename,
 such as nul on Windows.
@@ -916,7 +911,7 @@ or a syslog entry of the two forms:
   ErrorLog syslog:local7
 
 The particular subroutine for ErrorLog checks if the value is not
-equal to C<File::Spec->devnull>, does not begin with a | or does not
+equal to C<< File::Spec->devnull >>, does not begin with a | or does not
 match syslog(:[a-zA-Z0-9]+)?.
 
 These subroutines do not remove any "'s before checking on the type of
@@ -925,7 +920,7 @@ value.
 This hash is used by C<value_is_path> and C<orig_value_is_path>.
 
 This is a list of directives and any special values to check for as of
-Apache 1.3.20.
+Apache 1.3.20 with the addition of IncludeOptional from 2.4.x.
 
   AccessConfig
   AgentLog          check for "| prog"
@@ -944,6 +939,7 @@ Apache 1.3.20.
   DocumentRoot
   ErrorLog          check for "| prog", or syslog or syslog:facility
   Include
+  IncludeOptional
   LoadFile
   LoadModule
   LockFile
@@ -970,7 +966,7 @@ between directives that take only filenames, only directories or both.
 
 The hash value for the lowercase directive name is a subroutine
 reference.  The subroutine returns 1 if its only argument is a path
-and 0 otherwise.  The /dev/null equivalent (C<File::Spec->devnull>)
+and 0 otherwise.  The /dev/null equivalent (C<< File::Spec->devnull >>)
 for the operating system being used is not counted as a path, since on
 some operating systems the /dev/null equivalent is not a filename,
 such as nul on Windows.
@@ -993,7 +989,7 @@ or a syslog entry of the two forms:
   ErrorLog syslog:local7
 
 The particular subroutine for ErrorLog checks if the value is not
-equal to C<File::Spec->devnull>, does not begin with a | or does not
+equal to C<< File::Spec->devnull >>, does not begin with a | or does not
 match syslog(:[a-zA-Z0-9]+)?.
 
 These subroutines do not remove any "'s before checking on the type of
@@ -1003,7 +999,12 @@ This hash is used by C<value_is_rel_path> and
 C<orig_value_is_rel_path>.
 
 This is a list of directives and any special values to check for as of
-Apache 1.3.20.
+Apache 1.3.20 with the addition of IncludeOptional from 2.4.x.
+
+AccessFileName is not a key in the hash because, while its value is
+one or more relative paths, the ServerRoot is never prepended to it as
+the AccessFileName values are looked up in every directory of the path
+to the document being requested.
 
   AccessConfig
   AuthGroupFile
@@ -1012,6 +1013,7 @@ Apache 1.3.20.
   CustomLog         check for "| prog"
   ErrorLog          check for "| prog", or syslog or syslog:facility
   Include
+  IncludeOptional
   LoadFile
   LoadModule
   LockFile
@@ -1142,6 +1144,9 @@ my %directive_info = (
   Include           => ['0',
                         1,
                         \&directive_value_is_not_dev_null],
+  IncludeOptional   => ['0',
+                        1,
+                        \&directive_value_is_not_dev_null],
   LoadFile          => ['-0',
                         1,
                         \&directive_value_is_not_dev_null],
